@@ -76,7 +76,7 @@ class RootController(TGController):
 
     @expose('genshi:smallpress.templates.article')
     @validate(dict(article=SQLAEntityConverter(Article)), error_handler=index)
-    def view(self, article):
+    def view(self, article, **kw):
         visible = False
 
         if article.published and article.publish_date <= datetime.now():
