@@ -3,6 +3,7 @@ from tg import request, config
 from sqlalchemy import Table, ForeignKey, Column
 from sqlalchemy.types import Unicode, Integer, DateTime
 from sqlalchemy.orm import backref, relation
+from sqlalchemy.orm.interfaces import MapperExtension
 
 import os
 from datetime import datetime
@@ -36,6 +37,12 @@ class Blog(DeclarativeBase):
     name = Column(Unicode(100), nullable=False, default=u"Untitled", index=True)
 
 class Article(DeclarativeBase):
+    if not sqla_events:
+        class Hooks(MapperExtension):
+            def before_delete(self, mapper, connection, instance):
+                Article.before_delete(mapper, connection, instance)
+        __mapper_args__ = {'extension': Hooks()}
+
     __tablename__ = 'smallpress_articles'
 
     uid = Column(Integer, autoincrement=True, primary_key=True)
@@ -145,6 +152,12 @@ if sqla_events:
     event.listen(Article, 'before_delete', Article.before_delete)
 
 class Attachment(DeclarativeBase):
+    if not sqla_events:
+        class Hooks(MapperExtension):
+            def before_delete(self, mapper, connection, instance):
+                Attachment.delete_file(mapper, connection, instance)
+        __mapper_args__ = {'extension': Hooks()}
+
     __tablename__ = 'smallpress_attachments'
 
     uid = Column(Integer, autoincrement=True, primary_key=True)
