@@ -6,6 +6,8 @@ from smallpress.lib.forms import SearchForm
 
 search_form = SearchForm()
 
+WEEK_EXPIRE = 3600*24*7
+
 @expose('genshi:smallpress.templates.articles')
 def articles(articles=None, blog=None):
     if articles is None:
@@ -19,7 +21,7 @@ def article_preview(article):
         user = getattr(request.identity['user'], primary_key(app_model.User).key)
     return dict(article=article, tg_cache=dict(key='%s-%s-%s' % (article.uid, user,
                                                                  article.update_date.strftime('%Y-%m-%d_%H:%M:%S')),
-                                               expire=None,
+                                               expire=WEEK_EXPIRE,
                                                type='memory'))
 
 @expose('genshi:smallpress.templates.tagcloud')
@@ -33,3 +35,13 @@ def tagcloud(tags=None):
 def search():
     return dict(form=search_form, action=plug_url('smallpress', '/search'),
                 tg_cache=dict(key='search', expire=None, type='memory'))
+
+@expose('genshi:smallpress.templates.articles_excerpts')
+def excerpts(articles=None, blog=None):
+    if articles is None:
+        articles=Article.get_published(blog)
+    return dict(articles=articles)
+
+@expose('genshi:smallpress.templates.excerpt')
+def excerpt(article):
+    return article_preview(article)
